==> ding0-0.1.4.tar.gz: ding0-0.1.4/README.md <==
<img align="right" width="300" height="300" src="https://github.com/openego/ding0/blob/dev/doc/images/DING0_Logo_300px.png">

[![Documentation Status](https://readthedocs.org/projects/ding0/badge/?version=dev)](http://ding0.readthedocs.io/en/dev/?badge=dev)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.834751.svg)](https://doi.org/10.5281/zenodo.834751)

DING0
=====
DIstribution Network GeneratOr -- A tool to generate synthetic medium and low
voltage power distribution grids based on open (or at least accessible) data.

WARNING: Note, currently the data source Ding0 relies on - the
[Open Energy Database](http://oep.iks.cs.ovgu.de/dataedit/) - has no public
accessible API, yet. Thus, currently you won't be able to run Ding0 without
modifications.

Installation and usage
----------------------

Ding0 is provided through the package management tool *pip*. Install it by

```
pip3 install ding0
```

Further details regarding the installation including dependencies are provided
in the [documentation](https://ding0.readthedocs.io)

A [set of examples](https://ding0.readthedocs.io/en/dev/usage_details.html#examples)
is provided to show how to use Ding0.

An overview on versions of data already generated [can be found in the wiki](https://github.com/openego/ding0/wiki/Ding0-datasets).

LICENSE
-------

Copyright (C) 2017 openego project group

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU Affero General Public License as published by the Free
Software Foundation, either version 3 of the License, or (at your option) any
later version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program. If not, see https://www.gnu.org/licenses/.

==> ding0-0.1.5.tar.gz: ding0-0.1.5/README.md <==
<img align="right" width="300" height="300" src="https://github.com/openego/ding0/blob/dev/doc/images/DING0_Logo_300px.png">

[![Documentation Status](https://readthedocs.org/projects/ding0/badge/?version=dev)](http://ding0.readthedocs.io/en/dev/?badge=dev)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.834751.svg)](https://doi.org/10.5281/zenodo.834751)

DING0
=====
DIstribution Network GeneratOr -- A tool to generate synthetic medium and low
voltage power distribution grids based on open (or at least accessible) data.

WARNING: Note, currently the data source Ding0 relies on - the
[Open Energy Database](http://oep.iks.cs.ovgu.de/dataedit/) - has no public
accessible API, yet. Thus, currently you won't be able to run Ding0 without
modifications.

Installation and usage
----------------------

Ding0 is provided through the package management tool *pip*. Install it by

```
pip3 install ding0
```

Further details regarding the installation including dependencies are provided
in the [documentation](https://dingo.readthedocs.io)

A [set of examples](https://ding0.readthedocs.io/en/dev/usage_details.html#examples)
is provided to show how to use Ding0.

An overview on versions of data already generated [can be found in the wiki](https://github.com/openego/ding0/wiki/Ding0-datasets).

LICENSE
-------

Copyright (C) 2017 openego project group

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU Affero General Public License as published by the Free
Software Foundation, either version 3 of the License, or (at your option) any
later version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
details.

You should have received a copy of the GNU General Public License along with
this program. If not, see https://www.gnu.org/licenses/.
